@@ -112,11 +112,11 @@ as.party.J48 <- function(obj, ...) {
 
   ## construct metadata
   mf <- model.frame(obj)
-  mf_class <- sapply(mf, class)
+  mf_class <- sapply(mf, function(x) class(x)[1L])
   mf_levels <- lapply(mf, levels)
 
   x <- rJava::.jcall(obj$classifier, "S", "graph")
-  x <- RWeka:::parse_Weka_digraph(x, plainleaf = TRUE)
+  x <- parse_Weka_digraph(x, plainleaf = TRUE)
   nodes <- x$nodes
   edges <- x$edges
   is.leaf <- x$nodes[, "splitvar"] == ""
